sceAtracDecodeData

Function sceAtracDecodeData 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn sceAtracDecodeData( atrac_id: i32, out_samples: *mut u16, out_n: *mut i32, out_end: *mut i32, out_remain_frame: *mut i32, ) -> i32
Decode a frame of data.

Parameters

  • atrac_id: the atrac ID
  • out_samples: pointer to a buffer that receives the decoded data of the current frame
  • out_n: pointer to a integer that receives the number of audio samples of the decoded frame
  • out_end: pointer to a integer that receives a boolean value indicating if the decoded frame is the last one
  • out_remain_frame: pointer to a integer that receives either -1 if all at3 data is already on memory, or the remaining (not decoded yet) frames at memory if not all at3 data is on memory

Return Value

< 0 on error, otherwise 0