sceKernelReferThreadStatus

Function sceKernelReferThreadStatus 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn sceKernelReferThreadStatus( thid: SceUid, info: *mut SceKernelThreadInfo, ) -> i32
Get the status information for the specified thread.

Parameters

  • thid: Id of the thread to get status

  • info: Pointer to the info structure to receive the data.

    Note: The structures size field should be set to core::mem::size_of(SceKernelThreadInfo) before calling this function.

Return Value

0 if successful, otherwise the error code.