LightMode

Enum LightMode 

#[repr(u32)]
pub enum LightMode { SingleColor = 0, SeparateSpecularColor = 1, }
Light modes

Variants



SingleColor = 0



SeparateSpecularColor = 1

Separate specular colors are used to interpolate the specular component independently, so that it can be added to the fragment after the texture color.